@@ -24,6 +24,9 @@ class Exercise:
     difficulty: DifficultyLevel
     '''The difficulty level of the exercise.'''
 
+    error: SqlErrors
+    '''The SQL error type associated with the exercise.'''
+
     @staticmethod
     def generate(error: SqlErrors, difficulty: DifficultyLevel, dataset: Dataset, title: str) -> 'Exercise':
         '''Generate a SQL exercise based on the specified parameters.'''
@@ -95,7 +98,8 @@ The exercise must have the following characteristics: {error_details.characteris
                         title=title,
                         request=answer.request,
                         solutions=[answer.solution],
-                        difficulty=difficulty
+                        difficulty=difficulty,
+                        error=error
                     )
 
                 #validetion fail management
